<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Ya',
    'no' => 'Tidak',
    'update' => 'Perbarui',
    'save' => 'Simpan',
    'add' => 'Tambah',
    'cancel' => 'Batalkan',
    'confirm' => 'Konfirmasi',
    'delete_confirm' => 'Apakah Anda yakin?',
    'delete' => 'Hapus',
    'edit' => 'Sunting',
    'upload' => 'Unggah',
    'download' => 'Unduh',
    'save_close' => 'Simpan dan tutup dialog',
    'close' => 'Tutup',
    'copy' => 'Salin',
    'create' => 'Buat',
    'remove' => 'Hapus',
    'revoke' => 'Cabut',
    'done' => 'Selesai',
    'back' => 'Kembali',
    'verify' => 'Verifikasi',
    'new' => 'baru',
    'unknown' => 'Saya tidak tau',
    'load_more' => 'Muat lebih banyak',
    'loading' => 'Memuat…',
    'with' => 'dengan',
    'today' => 'hari ini',
    'yesterday' => 'kemarin',
    'another_day' => 'hari yang lain',
    'date' => 'Tanggal',
    'type' => 'Jenis',
    'zoom' => 'Perbesar',
    'upgrade' => 'Perbarui untuk membuka',
    'percent_uploaded' => '{percent}% diunggah',
    'retry' => 'Coba Lagi',
    'filter' => 'Filter daftar',
    'go_back' => 'Kembali',
    'file_selected' => '{count} berkas dipilih…',

    'application_title' => 'Monica – pengelola kontak relasi pribadi',
    'application_description' => 'Monica adalah sebuah alat untuk mengelola interaksi Anda dengan orang yang Anda sayangi, teman, dan keluarga.',
    'application_og_title' => 'Bangun hubungan yang lebih baik dengan orang yang Anda sayangi. CRM bebas untuk teman dan keluarga.',

    'markdown_description' => 'Ingin memformat teks Anda lebih bagus? Kami mendukung format Markdown untuk menambahkan tekstebal, italik, daftar, dan banyak lagi.',
    'markdown_link' => 'Baca dokumentasi',

    'header_settings_link' => 'Pengaturan',
    'header_logout_link' => 'Keluar',
    'header_changelog_link' => 'Perubahan produk',

    'main_nav_cta' => 'Tambah orang',
    'main_nav_dashboard' => 'Dasbor',
    'main_nav_family' => 'Kontak',
    'main_nav_journal' => 'Jurnal',
    'main_nav_activities' => 'Aktifitas',
    'main_nav_tasks' => 'Tugas',

    'footer_remarks' => 'Komentar?',
    'footer_send_email' => 'Kirim kami sebuah email',
    'footer_privacy' => 'Kebijakan privasi',
    'footer_release' => 'Catatan rilis',
    'footer_newsletter' => 'Newsletter',
    'footer_source_code' => 'Kontribusi',
    'footer_version' => 'Versi: :version',
    'footer_new_version' => 'Sebuah versi baru dari Monica tersedia',

    'footer_modal_version_whats_new' => 'Apa yang baru',
    'footer_modal_version_release_away' => 'Anda tertinggal :number rilisan dibelakang versi baru yang tersedia. Anda harus memperbarui pemasangan Anda.',

    'breadcrumb_dashboard' => 'Dasbor',
    'breadcrumb_list_contacts' => 'Daftar orang',
    'breadcrumb_archived_contacts' => 'Kontak yang diarsipkan',
    'breadcrumb_journal' => 'Jurnal',
    'breadcrumb_settings' => 'Pengaturan',
    'breadcrumb_settings_export' => 'Ekspor',
    'breadcrumb_settings_users' => 'Pengguna',
    'breadcrumb_settings_users_add' => 'Tambah seorang pengguna',
    'breadcrumb_settings_subscriptions' => 'Berlangganan',
    'breadcrumb_settings_import' => 'Impor',
    'breadcrumb_settings_import_report' => 'Impor laporan',
    'breadcrumb_settings_import_upload' => 'Unggah',
    'breadcrumb_settings_tags' => 'Tag',
    'breadcrumb_add_significant_other' => 'Tambahkan orang yang berarti',
    'breadcrumb_edit_significant_other' => 'Sunting orang yang berarti',
    'breadcrumb_add_note' => 'Tambah sebuah catatan',
    'breadcrumb_edit_note' => 'Sunting sebuah catatan',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'Sumberdaya DAV',
    'breadcrumb_edit_introductions' => 'Bagaimana Anda bertemu',
    'breadcrumb_settings_personalization' => 'Personalisasi',
    'breadcrumb_settings_security' => 'Keamanan',
    'breadcrumb_settings_security_2fa' => 'Otentikasi Dua Faktor',
    'breadcrumb_profile' => 'Profil dari :name',

    'gender_male' => 'Laki-laki',
    'gender_female' => 'Perempuan',
    'gender_none' => 'Lebih baik tidak mengatakan',
    'gender_no_gender' => 'Tidak ada jenis kelamin',

    'error_title' => 'Uppss Kakak! Suatu kesalahan telah terjadi.',
    'error_unauthorized' => 'Anda tidak punya izin untuk menyunting sumber daya ini.',
    'error_user_account' => 'Pengguna ini bukan termasuk dalam akun yang diberikan.',
    'error_save' => 'Kami mengalami kesalahan ketika mencoba menyimpan data.',
    'error_try_again' => 'Terjadi sesuatu kesalahan. Silahkan coba lagi.',
    'error_id' => 'ID Kesalahan: :id',
    'error_unavailable' => 'Layanan tidak tersedia',
    'error_maintenance' => 'Sedang dalam mode pemeliharaan. Kami akan segera kembali.',
    'error_help' => 'Kami akan segera kembali lagi.',
    'error_twitter' => 'Ikuti <a href="https://twitter.com/:twitter">akun Twitter kami</a> untuk pemberitahuan ketika sudah berjalan kembali.',
    'error_no_term' => 'Belum ada kebijakan untuk contoh ini.',

    'default_save_success' => 'Data telah disimpan.',

    'compliance_title' => 'Maaf untuk gangguan ini.',
    'compliance_desc' => 'Kami telah merubah <a href=":urlterm" hreflang=":hreflang">Ketentuan Penggunaan</a> dan <a href=":url" hreflang=":hreflang">Kebijakan Privasi</a> kami. Berdasarkan hukum, kami harus meminta Anda untuk meninjau kebijakan tersebut dan menyetujuinya agar Anda dapat melanjutkan untuk menggunakan akun Anda.',
    'compliance_desc_end' => 'Kami tidak melakukan sesuatu yang buruk terhadap data atau akun Anda dan kami tidak akan pernah melakukannya.',
    'compliance_terms' => 'Setujui ketentuan dan kebijakan privasi yang baru',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Hubungan percintaan',
    'relationship_type_group_family' => 'Hubungan keluarga',
    'relationship_type_group_friend' => 'Hubungan pertemanan',
    'relationship_type_group_work' => 'Hubungan pekerjaan',
    'relationship_type_group_other' => 'Jenis hubungan lainnya',

    'relationship_type_partner' => 'orang yang berarti',
    'relationship_type_partner_female' => 'orang yang berarti',
    'relationship_type_partner_male' => 'significant other',
    'relationship_type_partner_with_name' => ':name orang yang berarti lainnya',
    'relationship_type_partner_female_with_name' => ':name orang yang berarti lainnya',
    'relationship_type_partner_male_with_name' => ':name’s significant other',

    'relationship_type_spouse' => 'pasangan',
    'relationship_type_spouse_female' => 'wife',
    'relationship_type_spouse_male' => 'husband',
    'relationship_type_spouse_with_name' => 'pasangan :name',
    'relationship_type_spouse_female_with_name' => ':name’s wife',
    'relationship_type_spouse_male_with_name' => ':name’s husband',

    'relationship_type_date' => 'tanggal',
    'relationship_type_date_female' => 'tanggal',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => 'Tanggal :name',
    'relationship_type_date_female_with_name' => 'Tanggal :name',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'kekasih',
    'relationship_type_lover_female' => 'kekasih',
    'relationship_type_lover_male' => 'lover',
    'relationship_type_lover_with_name' => 'kekasih :name',
    'relationship_type_lover_female_with_name' => 'kekasih :name',
    'relationship_type_lover_male_with_name' => ':name’s lover',

    'relationship_type_inlovewith' => 'jatuh cinta dengan',
    'relationship_type_inlovewith_female' => 'jatuh cinta dengan',
    'relationship_type_inlovewith_male' => 'in love with',
    'relationship_type_inlovewith_with_name' => 'seseorang :name jatuh cinta dengan',
    'relationship_type_inlovewith_female_with_name' => 'seseorang :name jatuh cinta dengan',
    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',

    'relationship_type_lovedby' => 'dicintai oleh',
    'relationship_type_lovedby_female' => 'dicintai oleh',
    'relationship_type_lovedby_male' => 'loved by',
    'relationship_type_lovedby_with_name' => 'Kekasih rahasia :name',
    'relationship_type_lovedby_female_with_name' => 'Kekasih rahasia :name',
    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',

    'relationship_type_ex' => 'ex-partner',
    'relationship_type_ex_female' => 'mantan pacar',
    'relationship_type_ex_male' => 'ex-boyfriend',
    'relationship_type_ex_with_name' => ':name’s ex-partner',
    'relationship_type_ex_female_with_name' => 'Mantan pacar :name',
    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',

    'relationship_type_parent' => 'parent',
    'relationship_type_parent_female' => 'ibu',
    'relationship_type_parent_male' => 'father',
    'relationship_type_parent_with_name' => ':name’s parent',
    'relationship_type_parent_female_with_name' => 'Ibu :name',
    'relationship_type_parent_male_with_name' => ':name’s father',

    'relationship_type_child' => 'child',
    'relationship_type_child_female' => 'putri',
    'relationship_type_child_male' => 'son',
    'relationship_type_child_with_name' => ':name’s child',
    'relationship_type_child_female_with_name' => 'Putri :name',
    'relationship_type_child_male_with_name' => ':name’s son',

    'relationship_type_stepparent' => 'step-parent',
    'relationship_type_stepparent_female' => 'ibu tiri',
    'relationship_type_stepparent_male' => 'stepfather',
    'relationship_type_stepparent_with_name' => ':name’s step-parent',
    'relationship_type_stepparent_female_with_name' => 'Ibu tiri :name',
    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',

    'relationship_type_stepchild' => 'stepchild',
    'relationship_type_stepchild_female' => 'putri tiri',
    'relationship_type_stepchild_male' => 'stepson',
    'relationship_type_stepchild_with_name' => ':name’s stepchild',
    'relationship_type_stepchild_female_with_name' => 'Putri tiri :name',
    'relationship_type_stepchild_male_with_name' => ':name’s stepson',

    'relationship_type_sibling' => 'sibling',
    'relationship_type_sibling_female' => 'saudara perempuan',
    'relationship_type_sibling_male' => 'brother',
    'relationship_type_sibling_with_name' => ':name’s sibling',
    'relationship_type_sibling_female_with_name' => 'Saudara perempuan :name',
    'relationship_type_sibling_male_with_name' => ':name’s brother',

    'relationship_type_grandparent' => 'grandparent',
    'relationship_type_grandparent_female' => 'grandmother',
    'relationship_type_grandparent_male' => 'grandfather',
    'relationship_type_grandparent_with_name' => ':name’s grandparent',
    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',

    'relationship_type_grandchild' => 'grandchild',
    'relationship_type_grandchild_female' => 'granddaughter',
    'relationship_type_grandchild_male' => 'grandson',
    'relationship_type_grandchild_with_name' => ':name’s grandchild',
    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
    'relationship_type_grandchild_male_with_name' => ':name’s grandson',

    'relationship_type_uncle' => 'paman',
    'relationship_type_uncle_female' => 'bibi',
    'relationship_type_uncle_male' => 'uncle',
    'relationship_type_uncle_with_name' => 'Paman :name',
    'relationship_type_uncle_female_with_name' => 'Bibi :name',
    'relationship_type_uncle_male_with_name' => ':name’s uncle',

    'relationship_type_nephew' => 'keponakan',
    'relationship_type_nephew_female' => 'ponakan',
    'relationship_type_nephew_male' => 'nephew',
    'relationship_type_nephew_with_name' => 'Keponakan :name',
    'relationship_type_nephew_female_with_name' => 'Ponakan :name',
    'relationship_type_nephew_male_with_name' => ':name’s nephew',

    'relationship_type_cousin' => 'saudara',
    'relationship_type_cousin_female' => 'saudara',
    'relationship_type_cousin_male' => 'cousin',
    'relationship_type_cousin_with_name' => 'saudara :name',
    'relationship_type_cousin_female_with_name' => 'saudara :name',
    'relationship_type_cousin_male_with_name' => ':name’s cousin',

    'relationship_type_godfather' => 'godparent',
    'relationship_type_godfather_female' => 'wali perempuan',
    'relationship_type_godfather_male' => 'godfather',
    'relationship_type_godfather_with_name' => ':name’s godparent',
    'relationship_type_godfather_female_with_name' => 'Wali perempuan :name',
    'relationship_type_godfather_male_with_name' => ':name’s godfather',

    'relationship_type_godson' => 'godchild',
    'relationship_type_godson_female' => 'anak perempuan wali',
    'relationship_type_godson_male' => 'godson',
    'relationship_type_godson_with_name' => ':name’s godchild',
    'relationship_type_godson_female_with_name' => 'Anak perempuan wali :name',
    'relationship_type_godson_male_with_name' => ':name’s godson',

    'relationship_type_friend' => 'teman',
    'relationship_type_friend_female' => 'teman',
    'relationship_type_friend_male' => 'friend',
    'relationship_type_friend_with_name' => 'Teman :name',
    'relationship_type_friend_female_with_name' => 'Teman :name',
    'relationship_type_friend_male_with_name' => ':name’s friend',

    'relationship_type_bestfriend' => 'teman akrab',
    'relationship_type_bestfriend_female' => 'teman akrab',
    'relationship_type_bestfriend_male' => 'best friend',
    'relationship_type_bestfriend_with_name' => 'Sahabat :name',
    'relationship_type_bestfriend_female_with_name' => 'Sahabat :name',
    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',

    'relationship_type_colleague' => 'kolega',
    'relationship_type_colleague_female' => 'kolega',
    'relationship_type_colleague_male' => 'colleague',
    'relationship_type_colleague_with_name' => 'Kolega :name',
    'relationship_type_colleague_female_with_name' => 'Kolega :name',
    'relationship_type_colleague_male_with_name' => ':name’s colleague',

    'relationship_type_boss' => 'bos',
    'relationship_type_boss_female' => 'bos',
    'relationship_type_boss_male' => 'boss',
    'relationship_type_boss_with_name' => 'bos :name',
    'relationship_type_boss_female_with_name' => 'bos :name',
    'relationship_type_boss_male_with_name' => ':name’s boss',

    'relationship_type_subordinate' => 'bawahan',
    'relationship_type_subordinate_female' => 'bawahan',
    'relationship_type_subordinate_male' => 'subordinate',
    'relationship_type_subordinate_with_name' => 'bawahan :name',
    'relationship_type_subordinate_female_with_name' => 'bawahan :name',
    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',

    'relationship_type_mentor' => 'pelatih',
    'relationship_type_mentor_female' => 'pelatih',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => 'Pelatih :name',
    'relationship_type_mentor_female_with_name' => 'Pelatih :name',
    'relationship_type_mentor_male_with_name' => ':name’s mentor',

    'relationship_type_protege' => 'protégé',
    'relationship_type_protege_female' => 'protégé',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => ':name’s protégé',
    'relationship_type_protege_female_with_name' => ':name’s protégé',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'ex-spouse',
    'relationship_type_ex_husband_female' => 'mantan istri',
    'relationship_type_ex_husband_male' => 'ex-husband',
    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
    'relationship_type_ex_husband_female_with_name' => 'Mantan istri :name',
    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',

    // emotions
    'emotion_primary_love' => 'Percintaan',
    'emotion_primary_joy' => 'Gembira',
    'emotion_primary_surprise' => 'Kejutan',
    'emotion_primary_anger' => 'Marah',
    'emotion_primary_sadness' => 'Sedih',
    'emotion_primary_fear' => 'Takut',

    'emotion_secondary_affection' => 'Kasih sayang',
    'emotion_secondary_lust' => 'Nafsu',
    'emotion_secondary_longing' => 'Kangen',
    'emotion_secondary_cheerfulness' => 'Kegembiraan',
    'emotion_secondary_zest' => 'Gembira',
    'emotion_secondary_contentment' => 'Nafsu',
    'emotion_secondary_pride' => 'Kebanggaan',
    'emotion_secondary_optimism' => 'Optimisme',
    'emotion_secondary_enthrallment' => 'Kegirangan',
    'emotion_secondary_relief' => 'Kelegaan',
    'emotion_secondary_surprise' => 'Kejutan',
    'emotion_secondary_irritation' => 'Iritasi',
    'emotion_secondary_exasperation' => 'Kegembiraan',
    'emotion_secondary_rage' => 'Kemarahan',
    'emotion_secondary_disgust' => 'Kenajisan',
    'emotion_secondary_envy' => 'Iri',
    'emotion_secondary_suffering' => 'Kesakitan',
    'emotion_secondary_sadness' => 'Kesedihan',
    'emotion_secondary_disappointment' => 'Kecewa',
    'emotion_secondary_shame' => 'Malu',
    'emotion_secondary_neglect' => 'Ditinggalkan',
    'emotion_secondary_sympathy' => 'Simpati',
    'emotion_secondary_horror' => 'Kengerian',
    'emotion_secondary_nervousness' => 'Gerogi',

    'emotion_adoration' => 'Pemujaan',
    'emotion_affection' => 'Kasih sayang',
    'emotion_love' => 'Percintaan',
    'emotion_fondness' => 'Kesukaan',
    'emotion_liking' => 'Kesukaan',
    'emotion_attraction' => 'Daya Tarik',
    'emotion_caring' => 'Kepedulian',
    'emotion_tenderness' => 'Kelembutan',
    'emotion_compassion' => 'Belas Kasih',
    'emotion_sentimentality' => 'Sentimental',
    'emotion_arousal' => 'Gairah',
    'emotion_desire' => 'Keinginan',
    'emotion_lust' => 'Nafsu',
    'emotion_passion' => 'Semangat',
    'emotion_infatuation' => 'Jatuh Hati',
    'emotion_longing' => 'Kangen',
    'emotion_amusement' => 'Hiburan',
    'emotion_bliss' => 'Kebahagiaan',
    'emotion_cheerfulness' => 'Kegembiraan',
    'emotion_gaiety' => 'Keriangan',
    'emotion_glee' => 'Keriaan',
    'emotion_jolliness' => 'Kegirangan',
    'emotion_joviality' => 'Keriangan',
    'emotion_joy' => 'Gembira',
    'emotion_delight' => 'Kegembiraan',
    'emotion_enjoyment' => 'Kenikmatan',
    'emotion_gladness' => 'Kepuasan',
    'emotion_happiness' => 'Kebahagiaan',
    'emotion_jubilation' => 'Sorak Sorai',
    'emotion_elation' => 'Kegirangan Hati',
    'emotion_satisfaction' => 'Kepuasan',
    'emotion_ecstasy' => 'Sukacita',
    'emotion_euphoria' => 'Uforia',
    'emotion_enthusiasm' => 'Antusiasme',
    'emotion_zeal' => 'Semangat',
    'emotion_zest' => 'Gembira',
    'emotion_excitement' => 'Kegembiraan',
    'emotion_thrill' => 'Sensasi',
    'emotion_exhilaration' => 'Kegembiraan',
    'emotion_contentment' => 'Nafsu',
    'emotion_pleasure' => 'Kesenangan',
    'emotion_pride' => 'Kebanggaan',
    'emotion_eagerness' => 'Keinginan',
    'emotion_hope' => 'Harapan',
    'emotion_optimism' => 'Optimisme',
    'emotion_enthrallment' => 'Kegirangan',
    'emotion_rapture' => 'Kegirangan',
    'emotion_relief' => 'Kelegaan',
    'emotion_amazement' => 'Kekaguman',
    'emotion_surprise' => 'Kejutan',
    'emotion_astonishment' => 'Keheranan',
    'emotion_aggravation' => 'Kejengkelan',
    'emotion_irritation' => 'Iritasi',
    'emotion_agitation' => 'Agitasi',
    'emotion_annoyance' => 'Gangguan',
    'emotion_grouchiness' => 'Menggerutu',
    'emotion_grumpiness' => 'Sifat galak',
    'emotion_exasperation' => 'Kegembiraan',
    'emotion_frustration' => 'Frustrasi',
    'emotion_anger' => 'Marah',
    'emotion_rage' => 'Marah',
    'emotion_outrage' => 'Kekejaman',
    'emotion_fury' => 'Marah Besar',
    'emotion_wrath' => 'Wrath',
    'emotion_hostility' => 'Perseteruan',
    'emotion_ferocity' => 'Keganasan',
    'emotion_bitterness' => 'Kepahitan',
    'emotion_hate' => 'Benci',
    'emotion_loathing' => 'Kebencian',
    'emotion_scorn' => 'Cemooh',
    'emotion_spite' => 'Dendam',
    'emotion_vengefulness' => 'Rasa Dendam',
    'emotion_dislike' => 'Tidak suka',
    'emotion_resentment' => 'Kebencian',
    'emotion_disgust' => 'Kenajisan',
    'emotion_revulsion' => 'Rasa Muka',
    'emotion_contempt' => 'Penghinaan',
    'emotion_envy' => 'Iri',
    'emotion_jealousy' => 'Kecemburuan',
    'emotion_agony' => 'Penderitaan Mendalam',
    'emotion_suffering' => 'Kesakitan',
    'emotion_hurt' => 'Tersakiti',
    'emotion_anguish' => 'Penderitaan Berat',
    'emotion_depression' => 'Depresi',
    'emotion_despair' => 'Putus Asa',
    'emotion_hopelessness' => 'Keputusasan',
    'emotion_gloom' => 'Suram',
    'emotion_glumness' => 'Kesuraman',
    'emotion_sadness' => 'Kesedihan',
    'emotion_unhappiness' => 'Ketidakbahagiaan',
    'emotion_grief' => 'Duka',
    'emotion_sorrow' => 'Nestapa',
    'emotion_woe' => 'Duka',
    'emotion_misery' => 'Penderitaan',
    'emotion_melancholy' => 'Melankolis',
    'emotion_dismay' => 'Kecemasan',
    'emotion_disappointment' => 'Kecewa',
    'emotion_displeasure' => 'Ketidaksenangan',
    'emotion_guilt' => 'Rasa Bersalah',
    'emotion_shame' => 'Malu',
    'emotion_regret' => 'Penyesalan',
    'emotion_remorse' => 'Penyesalan',
    'emotion_alienation' => 'Pengasingan',
    'emotion_isolation' => 'Isolasi',
    'emotion_neglect' => 'Ditinggalkan',
    'emotion_loneliness' => 'Kesendirian',
    'emotion_rejection' => 'Penolakan',
    'emotion_homesickness' => 'Rindu Rumah',
    'emotion_defeat' => 'Kekalahan',
    'emotion_dejection' => 'Kekesalan',
    'emotion_insecurity' => 'Gelisah',
    'emotion_embarrassment' => 'Rasa Malu',
    'emotion_humiliation' => 'Penghinaan',
    'emotion_insult' => 'Menghina',
    'emotion_pity' => 'Mengasihani',
    'emotion_sympathy' => 'Simpati',
    'emotion_alarm' => 'Khawatir',
    'emotion_shock' => 'Syok',
    'emotion_fear' => 'Takut',
    'emotion_fright' => 'Ketakutan',
    'emotion_horror' => 'Kengerian',
    'emotion_terror' => 'Teror',
    'emotion_panic' => 'Panik',
    'emotion_hysteria' => 'Histeris',
    'emotion_mortification' => 'Malu',
    'emotion_anxiety' => 'Kegelisahan',
    'emotion_nervousness' => 'Gerogi',
    'emotion_tenseness' => 'Ketegangan',
    'emotion_uneasiness' => 'Rasa Gelisah',
    'emotion_apprehension' => 'Prihatin',
    'emotion_worry' => 'Khawatir',
    'emotion_distress' => 'Kesulitan',
    'emotion_dread' => 'Ketakutan',

    // weather
    'weather_sunny' => 'Sunny',
    'weather_clear' => 'Clear',
    'weather_clear-day' => 'Clear',
    'weather_clear-night' => 'Malam yang cerah',
    'weather_light-drizzle' => 'Light drizzle',
    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
    'weather_patchy-light-rain' => 'Patchy light rain',
    'weather_light-rain' => 'Light rain',
    'weather_moderate-rain-at-times' => 'Moderate rain at times',
    'weather_moderate-rain' => 'Moderate rain',
    'weather_patchy-rain-possible' => 'Patchy rain possible',
    'weather_heavy-rain-at-times' => 'Heavy rain at times',
    'weather_heavy-rain' => 'Heavy rain',
    'weather_light-freezing-rain' => 'Light freezing rain',
    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
    'weather_light-sleet' => 'Light sleet',
    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
    'weather_light-rain-shower' => 'Light rain shower',
    'weather_torrential-rain-shower' => 'Torrential rain shower',
    'weather_rain' => 'Hujan',
    'weather_snow' => 'Salju',
    'weather_blowing-snow' => 'Blowing snow',
    'weather_patchy-light-snow' => 'Patchy light snow',
    'weather_light-snow' => 'Light snow',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'Moderate snow',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'Heavy snow',
    'weather_light-snow-showers' => 'Light snow showers',
    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
    'weather_light-sleet-showers' => 'Light sleet showers',
    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
    'weather_sleet' => 'Hujan Es',
    'weather_wind' => 'Angin',
    'weather_fog' => 'Kabut',
    'weather_freezing-fog' => 'Freezing fog',
    'weather_mist' => 'Mist',
    'weather_blizzard' => 'Blizzard',
    'weather_overcast' => 'Overcast',
    'weather_cloudy' => 'Berawan',
    'weather_partly-cloudy-day' => 'Partly cloudy',
    'weather_partly-cloudy-night' => 'Partly cloudy',
    'weather_freezing-drizzle' => 'Freezing drizzle',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperatur °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Cuaca saat ini',

    // dav
    'dav_contacts' => 'Kontak',
    'dav_contacts_description' => 'Kontak :name',
    'dav_birthdays' => 'Ulang tahun',
    'dav_birthdays_description' => 'Ulang tahun kontak :name',
    'dav_tasks' => 'Tugas',
    'dav_tasks_description' => 'Tugas :name',

    // contact list
    'contact_list_avatar' => 'Avatar',
    'contact_list_name' => 'Kontak',
    'contact_list_description' => 'Deskripsi',

];
